# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractHumanUserUpdate:

    swagger_types = {
    
        'email_address': 'str',
        'firstname': 'str',
        'language': 'str',
        'lastname': 'str',
        'mobile_phone_number': 'str',
        'state': 'CreationEntityState',
        'time_zone': 'str',
        'two_factor_enabled': 'bool',
    }

    attribute_map = {
        'email_address': 'emailAddress','firstname': 'firstname','language': 'language','lastname': 'lastname','mobile_phone_number': 'mobilePhoneNumber','state': 'state','time_zone': 'timeZone','two_factor_enabled': 'twoFactorEnabled',
    }

    
    _email_address = None
    _firstname = None
    _language = None
    _lastname = None
    _mobile_phone_number = None
    _state = None
    _time_zone = None
    _two_factor_enabled = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.email_address = kwargs.get('email_address', None)
        self.firstname = kwargs.get('firstname', None)
        self.language = kwargs.get('language', None)
        self.lastname = kwargs.get('lastname', None)
        self.mobile_phone_number = kwargs.get('mobile_phone_number', None)
        self.state = kwargs.get('state', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.two_factor_enabled = kwargs.get('two_factor_enabled', None)
        

    
    @property
    def email_address(self):
        """Gets the email_address of this AbstractHumanUserUpdate.

            The email address of the user.

        :return: The email_address of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this AbstractHumanUserUpdate.

            The email address of the user.

        :param email_address: The email_address of this AbstractHumanUserUpdate.
        :type: str
        """
        if email_address is not None and len(email_address) > 128:
            raise ValueError("Invalid value for `email_address`, length must be less than or equal to `128`")

        self._email_address = email_address
    
    @property
    def firstname(self):
        """Gets the firstname of this AbstractHumanUserUpdate.

            The first name of the user.

        :return: The firstname of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this AbstractHumanUserUpdate.

            The first name of the user.

        :param firstname: The firstname of this AbstractHumanUserUpdate.
        :type: str
        """
        if firstname is not None and len(firstname) > 100:
            raise ValueError("Invalid value for `firstname`, length must be less than or equal to `100`")

        self._firstname = firstname
    
    @property
    def language(self):
        """Gets the language of this AbstractHumanUserUpdate.

            The preferred language of the user.

        :return: The language of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractHumanUserUpdate.

            The preferred language of the user.

        :param language: The language of this AbstractHumanUserUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def lastname(self):
        """Gets the lastname of this AbstractHumanUserUpdate.

            The last name of the user.

        :return: The lastname of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this AbstractHumanUserUpdate.

            The last name of the user.

        :param lastname: The lastname of this AbstractHumanUserUpdate.
        :type: str
        """
        if lastname is not None and len(lastname) > 100:
            raise ValueError("Invalid value for `lastname`, length must be less than or equal to `100`")

        self._lastname = lastname
    
    @property
    def mobile_phone_number(self):
        """Gets the mobile_phone_number of this AbstractHumanUserUpdate.

            

        :return: The mobile_phone_number of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._mobile_phone_number

    @mobile_phone_number.setter
    def mobile_phone_number(self, mobile_phone_number):
        """Sets the mobile_phone_number of this AbstractHumanUserUpdate.

            

        :param mobile_phone_number: The mobile_phone_number of this AbstractHumanUserUpdate.
        :type: str
        """
        if mobile_phone_number is not None and len(mobile_phone_number) > 30:
            raise ValueError("Invalid value for `mobile_phone_number`, length must be less than or equal to `30`")

        self._mobile_phone_number = mobile_phone_number
    
    @property
    def state(self):
        """Gets the state of this AbstractHumanUserUpdate.

            

        :return: The state of this AbstractHumanUserUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractHumanUserUpdate.

            

        :param state: The state of this AbstractHumanUserUpdate.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractHumanUserUpdate.

            The time zone which is applied for the user. If no timezone is specified the browser is used to determine an appropriate time zone.

        :return: The time_zone of this AbstractHumanUserUpdate.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractHumanUserUpdate.

            The time zone which is applied for the user. If no timezone is specified the browser is used to determine an appropriate time zone.

        :param time_zone: The time_zone of this AbstractHumanUserUpdate.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def two_factor_enabled(self):
        """Gets the two_factor_enabled of this AbstractHumanUserUpdate.

            Defines whether two-factor authentication is enabled for this user.

        :return: The two_factor_enabled of this AbstractHumanUserUpdate.
        :rtype: bool
        """
        return self._two_factor_enabled

    @two_factor_enabled.setter
    def two_factor_enabled(self, two_factor_enabled):
        """Sets the two_factor_enabled of this AbstractHumanUserUpdate.

            Defines whether two-factor authentication is enabled for this user.

        :param two_factor_enabled: The two_factor_enabled of this AbstractHumanUserUpdate.
        :type: bool
        """

        self._two_factor_enabled = two_factor_enabled
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractHumanUserUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractHumanUserUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class RenderedTerminalTransactionSummary:

    swagger_types = {
    
        'data': 'list[str]',
        'mime_type': 'str',
    }

    attribute_map = {
        'data': 'data','mime_type': 'mimeType',
    }

    
    _data = None
    _mime_type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.data = kwargs.get('data', None)
        self.mime_type = kwargs.get('mime_type', None)
        

    
    @property
    def data(self):
        """Gets the data of this RenderedTerminalTransactionSummary.

            The data property contains the binary data of the receipt document encoded as base 64 encoded string.

        :return: The data of this RenderedTerminalTransactionSummary.
        :rtype: list[str]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this RenderedTerminalTransactionSummary.

            The data property contains the binary data of the receipt document encoded as base 64 encoded string.

        :param data: The data of this RenderedTerminalTransactionSummary.
        :type: list[str]
        """

        self._data = data
    
    @property
    def mime_type(self):
        """Gets the mime_type of this RenderedTerminalTransactionSummary.

            The mime type indicates the format of the receipt document. The mime type depends on the requested receipt format.

        :return: The mime_type of this RenderedTerminalTransactionSummary.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this RenderedTerminalTransactionSummary.

            The mime type indicates the format of the receipt document. The mime type depends on the requested receipt format.

        :param mime_type: The mime_type of this RenderedTerminalTransactionSummary.
        :type: str
        """

        self._mime_type = mime_type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RenderedTerminalTransactionSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RenderedTerminalTransactionSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ChargeFlowLevelConfiguration:

    swagger_types = {
    
        'flow': 'ChargeFlow',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'period': 'str',
        'planned_purge_date': 'datetime',
        'priority': 'int',
        'state': 'CreationEntityState',
        'type': 'int',
        'version': 'int',
    }

    attribute_map = {
        'flow': 'flow','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','period': 'period','planned_purge_date': 'plannedPurgeDate','priority': 'priority','state': 'state','type': 'type','version': 'version',
    }

    
    _flow = None
    _id = None
    _linked_space_id = None
    _name = None
    _period = None
    _planned_purge_date = None
    _priority = None
    _state = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.flow = kwargs.get('flow', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.period = kwargs.get('period', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.priority = kwargs.get('priority', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def flow(self):
        """Gets the flow of this ChargeFlowLevelConfiguration.

            The charge flow level configuration to which the flow is associated.

        :return: The flow of this ChargeFlowLevelConfiguration.
        :rtype: ChargeFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this ChargeFlowLevelConfiguration.

            The charge flow level configuration to which the flow is associated.

        :param flow: The flow of this ChargeFlowLevelConfiguration.
        :type: ChargeFlow
        """

        self._flow = flow
    
    @property
    def id(self):
        """Gets the id of this ChargeFlowLevelConfiguration.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ChargeFlowLevelConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChargeFlowLevelConfiguration.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ChargeFlowLevelConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ChargeFlowLevelConfiguration.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this ChargeFlowLevelConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ChargeFlowLevelConfiguration.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this ChargeFlowLevelConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this ChargeFlowLevelConfiguration.

            The charge flow level configuration name is used internally to identify the charge flow level configuration. For example the name is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this ChargeFlowLevelConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChargeFlowLevelConfiguration.

            The charge flow level configuration name is used internally to identify the charge flow level configuration. For example the name is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this ChargeFlowLevelConfiguration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def period(self):
        """Gets the period of this ChargeFlowLevelConfiguration.

            The duration of the level before switching to the next one.

        :return: The period of this ChargeFlowLevelConfiguration.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this ChargeFlowLevelConfiguration.

            The duration of the level before switching to the next one.

        :param period: The period of this ChargeFlowLevelConfiguration.
        :type: str
        """

        self._period = period
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ChargeFlowLevelConfiguration.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this ChargeFlowLevelConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ChargeFlowLevelConfiguration.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this ChargeFlowLevelConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def priority(self):
        """Gets the priority of this ChargeFlowLevelConfiguration.

            The priority indicates the sort order of the level configurations. A low value indicates that the level configuration is executed before any level with a higher value. Any change to this value affects future level configuration selections.

        :return: The priority of this ChargeFlowLevelConfiguration.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ChargeFlowLevelConfiguration.

            The priority indicates the sort order of the level configurations. A low value indicates that the level configuration is executed before any level with a higher value. Any change to this value affects future level configuration selections.

        :param priority: The priority of this ChargeFlowLevelConfiguration.
        :type: int
        """

        self._priority = priority
    
    @property
    def state(self):
        """Gets the state of this ChargeFlowLevelConfiguration.

            

        :return: The state of this ChargeFlowLevelConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ChargeFlowLevelConfiguration.

            

        :param state: The state of this ChargeFlowLevelConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this ChargeFlowLevelConfiguration.

            The type determines how the payment link is delivered to the customer. Once the type is defined it cannot be changed anymore.

        :return: The type of this ChargeFlowLevelConfiguration.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChargeFlowLevelConfiguration.

            The type determines how the payment link is delivered to the customer. Once the type is defined it cannot be changed anymore.

        :param type: The type of this ChargeFlowLevelConfiguration.
        :type: int
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this ChargeFlowLevelConfiguration.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ChargeFlowLevelConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ChargeFlowLevelConfiguration.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ChargeFlowLevelConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ChargeFlowLevelConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ChargeFlowLevelConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class RestCountryState:

    swagger_types = {
    
        'code': 'str',
        'country_code': 'str',
        'id': 'str',
        'name': 'str',
    }

    attribute_map = {
        'code': 'code','country_code': 'countryCode','id': 'id','name': 'name',
    }

    
    _code = None
    _country_code = None
    _id = None
    _name = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.code = kwargs.get('code', None)
        self.country_code = kwargs.get('country_code', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        

    
    @property
    def code(self):
        """Gets the code of this RestCountryState.

            The code of the state identifies the state. The code is typically used within addresses. Some countries may not provide a code. For those the field is null.

        :return: The code of this RestCountryState.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this RestCountryState.

            The code of the state identifies the state. The code is typically used within addresses. Some countries may not provide a code. For those the field is null.

        :param code: The code of this RestCountryState.
        :type: str
        """

        self._code = code
    
    @property
    def country_code(self):
        """Gets the country_code of this RestCountryState.

            The country code in ISO two letter format (e.g. UK, DE, CH, US).

        :return: The country_code of this RestCountryState.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this RestCountryState.

            The country code in ISO two letter format (e.g. UK, DE, CH, US).

        :param country_code: The country_code of this RestCountryState.
        :type: str
        """

        self._country_code = country_code
    
    @property
    def id(self):
        """Gets the id of this RestCountryState.

            The ID of the state corresponds to the subdivision identifier defined in ISO 3166-2. The format consists of the country code followed by a dash and a subdivision identifier.

        :return: The id of this RestCountryState.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RestCountryState.

            The ID of the state corresponds to the subdivision identifier defined in ISO 3166-2. The format consists of the country code followed by a dash and a subdivision identifier.

        :param id: The id of this RestCountryState.
        :type: str
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this RestCountryState.

            The name is a human readable label of the state in the language of the region.

        :return: The name of this RestCountryState.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RestCountryState.

            The name is a human readable label of the state in the language of the region.

        :param name: The name of this RestCountryState.
        :type: str
        """

        self._name = name
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestCountryState, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestCountryState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class InvoiceReimbursement:

    swagger_types = {
    
        'amount': 'float',
        'created_on': 'datetime',
        'currency': 'str',
        'discarded_by': 'int',
        'discarded_on': 'datetime',
        'id': 'int',
        'linked_space_id': 'int',
        'payment_connector_configuration': 'PaymentConnectorConfiguration',
        'payment_initiation_advice_file': 'PaymentInitiationAdviceFile',
        'processed_by': 'int',
        'processed_on': 'datetime',
        'recipient_city': 'str',
        'recipient_country': 'str',
        'recipient_family_name': 'str',
        'recipient_given_name': 'str',
        'recipient_iban': 'str',
        'recipient_postcode': 'str',
        'recipient_street': 'str',
        'sender_iban': 'str',
        'state': 'InvoiceReimbursementState',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','created_on': 'createdOn','currency': 'currency','discarded_by': 'discardedBy','discarded_on': 'discardedOn','id': 'id','linked_space_id': 'linkedSpaceId','payment_connector_configuration': 'paymentConnectorConfiguration','payment_initiation_advice_file': 'paymentInitiationAdviceFile','processed_by': 'processedBy','processed_on': 'processedOn','recipient_city': 'recipientCity','recipient_country': 'recipientCountry','recipient_family_name': 'recipientFamilyName','recipient_given_name': 'recipientGivenName','recipient_iban': 'recipientIban','recipient_postcode': 'recipientPostcode','recipient_street': 'recipientStreet','sender_iban': 'senderIban','state': 'state','version': 'version',
    }

    
    _amount = None
    _created_on = None
    _currency = None
    _discarded_by = None
    _discarded_on = None
    _id = None
    _linked_space_id = None
    _payment_connector_configuration = None
    _payment_initiation_advice_file = None
    _processed_by = None
    _processed_on = None
    _recipient_city = None
    _recipient_country = None
    _recipient_family_name = None
    _recipient_given_name = None
    _recipient_iban = None
    _recipient_postcode = None
    _recipient_street = None
    _sender_iban = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.created_on = kwargs.get('created_on', None)
        self.currency = kwargs.get('currency', None)
        self.discarded_by = kwargs.get('discarded_by', None)
        self.discarded_on = kwargs.get('discarded_on', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.payment_connector_configuration = kwargs.get('payment_connector_configuration', None)
        self.payment_initiation_advice_file = kwargs.get('payment_initiation_advice_file', None)
        self.processed_by = kwargs.get('processed_by', None)
        self.processed_on = kwargs.get('processed_on', None)
        self.recipient_city = kwargs.get('recipient_city', None)
        self.recipient_country = kwargs.get('recipient_country', None)
        self.recipient_family_name = kwargs.get('recipient_family_name', None)
        self.recipient_given_name = kwargs.get('recipient_given_name', None)
        self.recipient_iban = kwargs.get('recipient_iban', None)
        self.recipient_postcode = kwargs.get('recipient_postcode', None)
        self.recipient_street = kwargs.get('recipient_street', None)
        self.sender_iban = kwargs.get('sender_iban', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this InvoiceReimbursement.

            

        :return: The amount of this InvoiceReimbursement.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceReimbursement.

            

        :param amount: The amount of this InvoiceReimbursement.
        :type: float
        """

        self._amount = amount
    
    @property
    def created_on(self):
        """Gets the created_on of this InvoiceReimbursement.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this InvoiceReimbursement.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this InvoiceReimbursement.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this InvoiceReimbursement.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def currency(self):
        """Gets the currency of this InvoiceReimbursement.

            

        :return: The currency of this InvoiceReimbursement.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceReimbursement.

            

        :param currency: The currency of this InvoiceReimbursement.
        :type: str
        """

        self._currency = currency
    
    @property
    def discarded_by(self):
        """Gets the discarded_by of this InvoiceReimbursement.

            

        :return: The discarded_by of this InvoiceReimbursement.
        :rtype: int
        """
        return self._discarded_by

    @discarded_by.setter
    def discarded_by(self, discarded_by):
        """Sets the discarded_by of this InvoiceReimbursement.

            

        :param discarded_by: The discarded_by of this InvoiceReimbursement.
        :type: int
        """

        self._discarded_by = discarded_by
    
    @property
    def discarded_on(self):
        """Gets the discarded_on of this InvoiceReimbursement.

            

        :return: The discarded_on of this InvoiceReimbursement.
        :rtype: datetime
        """
        return self._discarded_on

    @discarded_on.setter
    def discarded_on(self, discarded_on):
        """Sets the discarded_on of this InvoiceReimbursement.

            

        :param discarded_on: The discarded_on of this InvoiceReimbursement.
        :type: datetime
        """

        self._discarded_on = discarded_on
    
    @property
    def id(self):
        """Gets the id of this InvoiceReimbursement.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this InvoiceReimbursement.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceReimbursement.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this InvoiceReimbursement.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InvoiceReimbursement.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this InvoiceReimbursement.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InvoiceReimbursement.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this InvoiceReimbursement.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def payment_connector_configuration(self):
        """Gets the payment_connector_configuration of this InvoiceReimbursement.

            

        :return: The payment_connector_configuration of this InvoiceReimbursement.
        :rtype: PaymentConnectorConfiguration
        """
        return self._payment_connector_configuration

    @payment_connector_configuration.setter
    def payment_connector_configuration(self, payment_connector_configuration):
        """Sets the payment_connector_configuration of this InvoiceReimbursement.

            

        :param payment_connector_configuration: The payment_connector_configuration of this InvoiceReimbursement.
        :type: PaymentConnectorConfiguration
        """

        self._payment_connector_configuration = payment_connector_configuration
    
    @property
    def payment_initiation_advice_file(self):
        """Gets the payment_initiation_advice_file of this InvoiceReimbursement.

            

        :return: The payment_initiation_advice_file of this InvoiceReimbursement.
        :rtype: PaymentInitiationAdviceFile
        """
        return self._payment_initiation_advice_file

    @payment_initiation_advice_file.setter
    def payment_initiation_advice_file(self, payment_initiation_advice_file):
        """Sets the payment_initiation_advice_file of this InvoiceReimbursement.

            

        :param payment_initiation_advice_file: The payment_initiation_advice_file of this InvoiceReimbursement.
        :type: PaymentInitiationAdviceFile
        """

        self._payment_initiation_advice_file = payment_initiation_advice_file
    
    @property
    def processed_by(self):
        """Gets the processed_by of this InvoiceReimbursement.

            

        :return: The processed_by of this InvoiceReimbursement.
        :rtype: int
        """
        return self._processed_by

    @processed_by.setter
    def processed_by(self, processed_by):
        """Sets the processed_by of this InvoiceReimbursement.

            

        :param processed_by: The processed_by of this InvoiceReimbursement.
        :type: int
        """

        self._processed_by = processed_by
    
    @property
    def processed_on(self):
        """Gets the processed_on of this InvoiceReimbursement.

            

        :return: The processed_on of this InvoiceReimbursement.
        :rtype: datetime
        """
        return self._processed_on

    @processed_on.setter
    def processed_on(self, processed_on):
        """Sets the processed_on of this InvoiceReimbursement.

            

        :param processed_on: The processed_on of this InvoiceReimbursement.
        :type: datetime
        """

        self._processed_on = processed_on
    
    @property
    def recipient_city(self):
        """Gets the recipient_city of this InvoiceReimbursement.

            

        :return: The recipient_city of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_city

    @recipient_city.setter
    def recipient_city(self, recipient_city):
        """Sets the recipient_city of this InvoiceReimbursement.

            

        :param recipient_city: The recipient_city of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_city = recipient_city
    
    @property
    def recipient_country(self):
        """Gets the recipient_country of this InvoiceReimbursement.

            

        :return: The recipient_country of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """Sets the recipient_country of this InvoiceReimbursement.

            

        :param recipient_country: The recipient_country of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_country = recipient_country
    
    @property
    def recipient_family_name(self):
        """Gets the recipient_family_name of this InvoiceReimbursement.

            

        :return: The recipient_family_name of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_family_name

    @recipient_family_name.setter
    def recipient_family_name(self, recipient_family_name):
        """Sets the recipient_family_name of this InvoiceReimbursement.

            

        :param recipient_family_name: The recipient_family_name of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_family_name = recipient_family_name
    
    @property
    def recipient_given_name(self):
        """Gets the recipient_given_name of this InvoiceReimbursement.

            

        :return: The recipient_given_name of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_given_name

    @recipient_given_name.setter
    def recipient_given_name(self, recipient_given_name):
        """Sets the recipient_given_name of this InvoiceReimbursement.

            

        :param recipient_given_name: The recipient_given_name of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_given_name = recipient_given_name
    
    @property
    def recipient_iban(self):
        """Gets the recipient_iban of this InvoiceReimbursement.

            

        :return: The recipient_iban of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_iban

    @recipient_iban.setter
    def recipient_iban(self, recipient_iban):
        """Sets the recipient_iban of this InvoiceReimbursement.

            

        :param recipient_iban: The recipient_iban of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_iban = recipient_iban
    
    @property
    def recipient_postcode(self):
        """Gets the recipient_postcode of this InvoiceReimbursement.

            

        :return: The recipient_postcode of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_postcode

    @recipient_postcode.setter
    def recipient_postcode(self, recipient_postcode):
        """Sets the recipient_postcode of this InvoiceReimbursement.

            

        :param recipient_postcode: The recipient_postcode of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_postcode = recipient_postcode
    
    @property
    def recipient_street(self):
        """Gets the recipient_street of this InvoiceReimbursement.

            

        :return: The recipient_street of this InvoiceReimbursement.
        :rtype: str
        """
        return self._recipient_street

    @recipient_street.setter
    def recipient_street(self, recipient_street):
        """Sets the recipient_street of this InvoiceReimbursement.

            

        :param recipient_street: The recipient_street of this InvoiceReimbursement.
        :type: str
        """

        self._recipient_street = recipient_street
    
    @property
    def sender_iban(self):
        """Gets the sender_iban of this InvoiceReimbursement.

            

        :return: The sender_iban of this InvoiceReimbursement.
        :rtype: str
        """
        return self._sender_iban

    @sender_iban.setter
    def sender_iban(self, sender_iban):
        """Sets the sender_iban of this InvoiceReimbursement.

            

        :param sender_iban: The sender_iban of this InvoiceReimbursement.
        :type: str
        """

        self._sender_iban = sender_iban
    
    @property
    def state(self):
        """Gets the state of this InvoiceReimbursement.

            

        :return: The state of this InvoiceReimbursement.
        :rtype: InvoiceReimbursementState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InvoiceReimbursement.

            

        :param state: The state of this InvoiceReimbursement.
        :type: InvoiceReimbursementState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this InvoiceReimbursement.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this InvoiceReimbursement.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InvoiceReimbursement.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this InvoiceReimbursement.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InvoiceReimbursement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InvoiceReimbursement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from postfinancecheckout.api_client import ApiClient

class TransactionServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def confirm(self, space_id, transaction_model, **kwargs):
        """Confirm

        The confirm operation marks the transaction as confirmed. Once the transaction is confirmed no more changes can be applied.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm(space_id, transaction_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionPending transaction_model: The transaction JSON object to update and confirm. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.confirm_with_http_info(space_id, transaction_model, **kwargs)
        else:
            (data) = self.confirm_with_http_info(space_id, transaction_model, **kwargs)
            return data

    def confirm_with_http_info(self, space_id, transaction_model, **kwargs):
        """Confirm

        The confirm operation marks the transaction as confirmed. Once the transaction is confirmed no more changes can be applied.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_with_http_info(space_id, transaction_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionPending transaction_model: The transaction JSON object to update and confirm. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction_model']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `confirm`")
        # verify the required parameter 'transaction_model' is set
        if ('transaction_model' not in params or
                params['transaction_model'] is None):
            raise ValueError("Missing the required parameter `transaction_model` when calling `confirm`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'transaction_model' in params:
            body_params = params['transaction_model']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create(self, space_id, transaction, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(space_id, transaction, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionCreate transaction: The transaction object which should be created. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.create_with_http_info(space_id, transaction, **kwargs)
        else:
            (data) = self.create_with_http_info(space_id, transaction, **kwargs)
            return data

    def create_with_http_info(self, space_id, transaction, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(space_id, transaction, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionCreate transaction: The transaction object which should be created. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create`")
        # verify the required parameter 'transaction' is set
        if ('transaction' not in params or
                params['transaction'] is None):
            raise ValueError("Missing the required parameter `transaction` when calling `create`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'transaction' in params:
            body_params = params['transaction']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_transaction_credentials(self, space_id, id, **kwargs):
        """Create Transaction Credentials

        This operation allows to create transaction credentials to delegate temporarily the access to the web service API for this particular transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transaction_credentials(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.create_transaction_credentials_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.create_transaction_credentials_with_http_info(space_id, id, **kwargs)
            return data

    def create_transaction_credentials_with_http_info(self, space_id, id, **kwargs):
        """Create Transaction Credentials

        This operation allows to create transaction credentials to delegate temporarily the access to the web service API for this particular transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transaction_credentials_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_transaction_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create_transaction_credentials`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_transaction_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/createTransactionCredentials', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_one_click_token_with_credentials(self, credentials, token_id, **kwargs):
        """Delete One-Click Token with Credentials

        This operation removes the given token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_one_click_token_with_credentials(credentials, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param int token_id: The token ID will be used to find the token which should be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.delete_one_click_token_with_credentials_with_http_info(credentials, token_id, **kwargs)
        else:
            (data) = self.delete_one_click_token_with_credentials_with_http_info(credentials, token_id, **kwargs)
            return data

    def delete_one_click_token_with_credentials_with_http_info(self, credentials, token_id, **kwargs):
        """Delete One-Click Token with Credentials

        This operation removes the given token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_one_click_token_with_credentials_with_http_info(credentials, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param int token_id: The token ID will be used to find the token which should be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials', 'token_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_one_click_token_with_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `delete_one_click_token_with_credentials`")
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `delete_one_click_token_with_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'credentials' in params:
            query_params.append(('credentials', params['credentials']))
        if 'token_id' in params:
            query_params.append(('tokenId', params['token_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/deleteOneClickTokenWithCredentials', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export(self, space_id, request, **kwargs):
        """Export

        Exports the transactions into a CSV file. The file will contain the properties defined in the request.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityExportRequest request: The request controls the entries which are exported. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.export_with_http_info(space_id, request, **kwargs)
        else:
            (data) = self.export_with_http_info(space_id, request, **kwargs)
            return data

    def export_with_http_info(self, space_id, request, **kwargs):
        """Export

        Exports the transactions into a CSV file. The file will contain the properties defined in the request.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_with_http_info(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityExportRequest request: The request controls the entries which are exported. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `export`")
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `export`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8', 'text/csv'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_one_click_tokens_with_credentials(self, credentials, **kwargs):
        """Fetch One Click Tokens with Credentials

        This operation returns the token version objects which references the tokens usable as one-click payment tokens for the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_one_click_tokens_with_credentials(credentials, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :return: list[TokenVersion]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.fetch_one_click_tokens_with_credentials_with_http_info(credentials, **kwargs)
        else:
            (data) = self.fetch_one_click_tokens_with_credentials_with_http_info(credentials, **kwargs)
            return data

    def fetch_one_click_tokens_with_credentials_with_http_info(self, credentials, **kwargs):
        """Fetch One Click Tokens with Credentials

        This operation returns the token version objects which references the tokens usable as one-click payment tokens for the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_one_click_tokens_with_credentials_with_http_info(credentials, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :return: list[TokenVersion]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_one_click_tokens_with_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `fetch_one_click_tokens_with_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'credentials' in params:
            query_params.append(('credentials', params['credentials']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/fetchOneClickTokensWithCredentials', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TokenVersion]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_payment_methods(self, space_id, id, integration_mode, **kwargs):
        """Fetch Possible Payment Methods

        This operation allows to get the payment method configurations which can be used with the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_payment_methods(space_id, id, integration_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :param str integration_mode: The integration mode defines the type of integration that is applied on the transaction. (required)
        :return: list[PaymentMethodConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.fetch_payment_methods_with_http_info(space_id, id, integration_mode, **kwargs)
        else:
            (data) = self.fetch_payment_methods_with_http_info(space_id, id, integration_mode, **kwargs)
            return data

    def fetch_payment_methods_with_http_info(self, space_id, id, integration_mode, **kwargs):
        """Fetch Possible Payment Methods

        This operation allows to get the payment method configurations which can be used with the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_payment_methods_with_http_info(space_id, id, integration_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :param str integration_mode: The integration mode defines the type of integration that is applied on the transaction. (required)
        :return: list[PaymentMethodConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id', 'integration_mode']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_payment_methods" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `fetch_payment_methods`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `fetch_payment_methods`")
        # verify the required parameter 'integration_mode' is set
        if ('integration_mode' not in params or
                params['integration_mode'] is None):
            raise ValueError("Missing the required parameter `integration_mode` when calling `fetch_payment_methods`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))
        if 'integration_mode' in params:
            query_params.append(('integrationMode', params['integration_mode']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/fetch-payment-methods', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentMethodConfiguration]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_payment_methods_with_credentials(self, credentials, integration_mode, **kwargs):
        """Fetch Possible Payment Methods with Credentials

        This operation allows to get the payment method configurations which can be used with the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_payment_methods_with_credentials(credentials, integration_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param str integration_mode: The integration mode defines the type of integration that is applied on the transaction. (required)
        :return: list[PaymentMethodConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.fetch_payment_methods_with_credentials_with_http_info(credentials, integration_mode, **kwargs)
        else:
            (data) = self.fetch_payment_methods_with_credentials_with_http_info(credentials, integration_mode, **kwargs)
            return data

    def fetch_payment_methods_with_credentials_with_http_info(self, credentials, integration_mode, **kwargs):
        """Fetch Possible Payment Methods with Credentials

        This operation allows to get the payment method configurations which can be used with the provided transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_payment_methods_with_credentials_with_http_info(credentials, integration_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param str integration_mode: The integration mode defines the type of integration that is applied on the transaction. (required)
        :return: list[PaymentMethodConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials', 'integration_mode']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_payment_methods_with_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `fetch_payment_methods_with_credentials`")
        # verify the required parameter 'integration_mode' is set
        if ('integration_mode' not in params or
                params['integration_mode'] is None):
            raise ValueError("Missing the required parameter `integration_mode` when calling `fetch_payment_methods_with_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'credentials' in params:
            query_params.append(('credentials', params['credentials']))
        if 'integration_mode' in params:
            query_params.append(('integrationMode', params['integration_mode']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/fetch-payment-methods-with-credentials', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentMethodConfiguration]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_invoice_document(self, space_id, id, **kwargs):
        """getInvoiceDocument

        Returns the PDF document for the transaction invoice with given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_invoice_document(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the invoice document for. (required)
        :return: RenderedDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.get_invoice_document_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.get_invoice_document_with_http_info(space_id, id, **kwargs)
            return data

    def get_invoice_document_with_http_info(self, space_id, id, **kwargs):
        """getInvoiceDocument

        Returns the PDF document for the transaction invoice with given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_invoice_document_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the invoice document for. (required)
        :return: RenderedDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_invoice_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `get_invoice_document`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_invoice_document`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/getInvoiceDocument', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RenderedDocument',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_latest_transaction_line_item_version(self, space_id, id, **kwargs):
        """getLatestSuccessfulTransactionLineItemVersion

        
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_transaction_line_item_version(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the latest line item version for. (required)
        :return: TransactionLineItemVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.get_latest_transaction_line_item_version_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.get_latest_transaction_line_item_version_with_http_info(space_id, id, **kwargs)
            return data

    def get_latest_transaction_line_item_version_with_http_info(self, space_id, id, **kwargs):
        """getLatestSuccessfulTransactionLineItemVersion

        
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_transaction_line_item_version_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the latest line item version for. (required)
        :return: TransactionLineItemVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_latest_transaction_line_item_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `get_latest_transaction_line_item_version`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_latest_transaction_line_item_version`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/getLatestTransactionLineItemVersion', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TransactionLineItemVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_packing_slip(self, space_id, id, **kwargs):
        """getPackingSlip

        Returns the packing slip for the transaction with given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packing_slip(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the packing slip for. (required)
        :return: RenderedDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.get_packing_slip_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.get_packing_slip_with_http_info(space_id, id, **kwargs)
            return data

    def get_packing_slip_with_http_info(self, space_id, id, **kwargs):
        """getPackingSlip

        Returns the packing slip for the transaction with given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packing_slip_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction to get the packing slip for. (required)
        :return: RenderedDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_packing_slip" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `get_packing_slip`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_packing_slip`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/getPackingSlip', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RenderedDocument',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_one_click_token_and_redirect_with_credentials(self, credentials, token_id, **kwargs):
        """Process One-Click Token with Credentials

        This operation assigns the given token to the transaction and process it. This method will return an URL where the customer has to be redirect to complete the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_one_click_token_and_redirect_with_credentials(credentials, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param int token_id: The token ID is used to load the corresponding token and to process the transaction with it. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.process_one_click_token_and_redirect_with_credentials_with_http_info(credentials, token_id, **kwargs)
        else:
            (data) = self.process_one_click_token_and_redirect_with_credentials_with_http_info(credentials, token_id, **kwargs)
            return data

    def process_one_click_token_and_redirect_with_credentials_with_http_info(self, credentials, token_id, **kwargs):
        """Process One-Click Token with Credentials

        This operation assigns the given token to the transaction and process it. This method will return an URL where the customer has to be redirect to complete the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_one_click_token_and_redirect_with_credentials_with_http_info(credentials, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :param int token_id: The token ID is used to load the corresponding token and to process the transaction with it. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials', 'token_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_one_click_token_and_redirect_with_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `process_one_click_token_and_redirect_with_credentials`")
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `process_one_click_token_and_redirect_with_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'credentials' in params:
            query_params.append(('credentials', params['credentials']))
        if 'token_id' in params:
            query_params.append(('tokenId', params['token_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/processOneClickTokenAndRedirectWithCredentials', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_without_user_interaction(self, space_id, id, **kwargs):
        """Process Without User Interaction

        This operation processes the transaction without requiring that the customer is present. Means this operation applies strategies to process the transaction without a direct interaction with the buyer. This operation is suitable for recurring transactions.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_without_user_interaction(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be processed. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.process_without_user_interaction_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.process_without_user_interaction_with_http_info(space_id, id, **kwargs)
            return data

    def process_without_user_interaction_with_http_info(self, space_id, id, **kwargs):
        """Process Without User Interaction

        This operation processes the transaction without requiring that the customer is present. Means this operation applies strategies to process the transaction without a direct interaction with the buyer. This operation is suitable for recurring transactions.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_without_user_interaction_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be processed. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_without_user_interaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `process_without_user_interaction`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `process_without_user_interaction`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/processWithoutUserInteraction', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be returned. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read_with_credentials(self, credentials, **kwargs):
        """Read With Credentials

        Reads the transaction with the given 'id' and returns it. This method uses the credentials to authenticate and identify the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_credentials(credentials, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.read_with_credentials_with_http_info(credentials, **kwargs)
        else:
            (data) = self.read_with_credentials_with_http_info(credentials, **kwargs)
            return data

    def read_with_credentials_with_http_info(self, credentials, **kwargs):
        """Read With Credentials

        Reads the transaction with the given 'id' and returns it. This method uses the credentials to authenticate and identify the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_credentials_with_http_info(credentials, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credentials: The credentials identifies the transaction and contains the security details which grants the access this operation. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read_with_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `read_with_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'credentials' in params:
            query_params.append(('credentials', params['credentials']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/readWithCredentials', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the transactions which are returned by the search. (required)
        :return: list[Transaction]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the transactions which are returned by the search. (required)
        :return: list[Transaction]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Transaction]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionPending entity: The transaction object with the properties which should be updated. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.update_with_http_info(space_id, entity, **kwargs)
        else:
            (data) = self.update_with_http_info(space_id, entity, **kwargs)
            return data

    def update_with_http_info(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_with_http_info(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TransactionPending entity: The transaction object with the properties which should be updated. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'entity']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `update`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params or
                params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `update`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entity' in params:
            body_params = params['entity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum



class RenderedTerminalReceipt:

    swagger_types = {
    
        'data': 'list[str]',
        'mime_type': 'str',
        'printed': 'bool',
        'receipt_type': 'PaymentTerminalReceiptType',
    }

    attribute_map = {
        'data': 'data','mime_type': 'mimeType','printed': 'printed','receipt_type': 'receiptType',
    }

    
    _data = None
    _mime_type = None
    _printed = None
    _receipt_type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.data = kwargs.get('data', None)
        self.mime_type = kwargs.get('mime_type', None)
        self.printed = kwargs.get('printed', None)
        self.receipt_type = kwargs.get('receipt_type', None)
        

    
    @property
    def data(self):
        """Gets the data of this RenderedTerminalReceipt.

            The data property contains the binary data of the receipt document encoded as base 64 encoded string.

        :return: The data of this RenderedTerminalReceipt.
        :rtype: list[str]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this RenderedTerminalReceipt.

            The data property contains the binary data of the receipt document encoded as base 64 encoded string.

        :param data: The data of this RenderedTerminalReceipt.
        :type: list[str]
        """

        self._data = data
    
    @property
    def mime_type(self):
        """Gets the mime_type of this RenderedTerminalReceipt.

            The mime type indicates the format of the receipt document. The mime type depends on the requested receipt format.

        :return: The mime_type of this RenderedTerminalReceipt.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this RenderedTerminalReceipt.

            The mime type indicates the format of the receipt document. The mime type depends on the requested receipt format.

        :param mime_type: The mime_type of this RenderedTerminalReceipt.
        :type: str
        """

        self._mime_type = mime_type
    
    @property
    def printed(self):
        """Gets the printed of this RenderedTerminalReceipt.

            The terminal might or might not print the receipt. This property is set to true when the configuration of the terminal forces the printing and the device supports the receipt printing.

        :return: The printed of this RenderedTerminalReceipt.
        :rtype: bool
        """
        return self._printed

    @printed.setter
    def printed(self, printed):
        """Sets the printed of this RenderedTerminalReceipt.

            The terminal might or might not print the receipt. This property is set to true when the configuration of the terminal forces the printing and the device supports the receipt printing.

        :param printed: The printed of this RenderedTerminalReceipt.
        :type: bool
        """

        self._printed = printed
    
    @property
    def receipt_type(self):
        """Gets the receipt_type of this RenderedTerminalReceipt.

            Each receipt has a different usage. The receipt type indicates for what resp. for whom the document is for.

        :return: The receipt_type of this RenderedTerminalReceipt.
        :rtype: PaymentTerminalReceiptType
        """
        return self._receipt_type

    @receipt_type.setter
    def receipt_type(self, receipt_type):
        """Sets the receipt_type of this RenderedTerminalReceipt.

            Each receipt has a different usage. The receipt type indicates for what resp. for whom the document is for.

        :param receipt_type: The receipt_type of this RenderedTerminalReceipt.
        :type: PaymentTerminalReceiptType
        """

        self._receipt_type = receipt_type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RenderedTerminalReceipt, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RenderedTerminalReceipt):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class RestLanguage:

    swagger_types = {
    
        'country_code': 'str',
        'ietf_code': 'str',
        'iso2_code': 'str',
        'iso3_code': 'str',
        'plural_expression': 'str',
        'primary_of_group': 'bool',
    }

    attribute_map = {
        'country_code': 'countryCode','ietf_code': 'ietfCode','iso2_code': 'iso2Code','iso3_code': 'iso3Code','plural_expression': 'pluralExpression','primary_of_group': 'primaryOfGroup',
    }

    
    _country_code = None
    _ietf_code = None
    _iso2_code = None
    _iso3_code = None
    _plural_expression = None
    _primary_of_group = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.country_code = kwargs.get('country_code', None)
        self.ietf_code = kwargs.get('ietf_code', None)
        self.iso2_code = kwargs.get('iso2_code', None)
        self.iso3_code = kwargs.get('iso3_code', None)
        self.plural_expression = kwargs.get('plural_expression', None)
        self.primary_of_group = kwargs.get('primary_of_group', None)
        

    
    @property
    def country_code(self):
        """Gets the country_code of this RestLanguage.

            The country code represents the region of the language as a 2 letter ISO code.

        :return: The country_code of this RestLanguage.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this RestLanguage.

            The country code represents the region of the language as a 2 letter ISO code.

        :param country_code: The country_code of this RestLanguage.
        :type: str
        """

        self._country_code = country_code
    
    @property
    def ietf_code(self):
        """Gets the ietf_code of this RestLanguage.

            The IETF code represents the language as the two letter ISO code including the region (e.g. en-US).

        :return: The ietf_code of this RestLanguage.
        :rtype: str
        """
        return self._ietf_code

    @ietf_code.setter
    def ietf_code(self, ietf_code):
        """Sets the ietf_code of this RestLanguage.

            The IETF code represents the language as the two letter ISO code including the region (e.g. en-US).

        :param ietf_code: The ietf_code of this RestLanguage.
        :type: str
        """

        self._ietf_code = ietf_code
    
    @property
    def iso2_code(self):
        """Gets the iso2_code of this RestLanguage.

            The ISO 2 letter code represents the language with two letters.

        :return: The iso2_code of this RestLanguage.
        :rtype: str
        """
        return self._iso2_code

    @iso2_code.setter
    def iso2_code(self, iso2_code):
        """Sets the iso2_code of this RestLanguage.

            The ISO 2 letter code represents the language with two letters.

        :param iso2_code: The iso2_code of this RestLanguage.
        :type: str
        """

        self._iso2_code = iso2_code
    
    @property
    def iso3_code(self):
        """Gets the iso3_code of this RestLanguage.

            The ISO 3 letter code represents the language with three letters.

        :return: The iso3_code of this RestLanguage.
        :rtype: str
        """
        return self._iso3_code

    @iso3_code.setter
    def iso3_code(self, iso3_code):
        """Sets the iso3_code of this RestLanguage.

            The ISO 3 letter code represents the language with three letters.

        :param iso3_code: The iso3_code of this RestLanguage.
        :type: str
        """

        self._iso3_code = iso3_code
    
    @property
    def plural_expression(self):
        """Gets the plural_expression of this RestLanguage.

            The plural expression defines how to map a plural into the language index. This expression is used to determine the plural form for the translations.

        :return: The plural_expression of this RestLanguage.
        :rtype: str
        """
        return self._plural_expression

    @plural_expression.setter
    def plural_expression(self, plural_expression):
        """Sets the plural_expression of this RestLanguage.

            The plural expression defines how to map a plural into the language index. This expression is used to determine the plural form for the translations.

        :param plural_expression: The plural_expression of this RestLanguage.
        :type: str
        """

        self._plural_expression = plural_expression
    
    @property
    def primary_of_group(self):
        """Gets the primary_of_group of this RestLanguage.

            The primary language of a group indicates whether a language is the primary language of a group of languages. The group is determine by the ISO 2 letter code.

        :return: The primary_of_group of this RestLanguage.
        :rtype: bool
        """
        return self._primary_of_group

    @primary_of_group.setter
    def primary_of_group(self, primary_of_group):
        """Sets the primary_of_group of this RestLanguage.

            The primary language of a group indicates whether a language is the primary language of a group of languages. The group is determine by the ISO 2 letter code.

        :param primary_of_group: The primary_of_group of this RestLanguage.
        :type: bool
        """

        self._primary_of_group = primary_of_group
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestLanguage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestLanguage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionSuspensionCreate:

    swagger_types = {
    
        'planned_end_date': 'datetime',
        'subscription': 'int',
        'type': 'ShopifySubscriptionSuspensionType',
    }

    attribute_map = {
        'planned_end_date': 'plannedEndDate','subscription': 'subscription','type': 'type',
    }

    
    _planned_end_date = None
    _subscription = None
    _type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.planned_end_date = kwargs.get('planned_end_date')

        self.subscription = kwargs.get('subscription')

        self.type = kwargs.get('type')

        

    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this ShopifySubscriptionSuspensionCreate.

            

        :return: The planned_end_date of this ShopifySubscriptionSuspensionCreate.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this ShopifySubscriptionSuspensionCreate.

            

        :param planned_end_date: The planned_end_date of this ShopifySubscriptionSuspensionCreate.
        :type: datetime
        """
        if planned_end_date is None:
            raise ValueError("Invalid value for `planned_end_date`, must not be `None`")

        self._planned_end_date = planned_end_date
    
    @property
    def subscription(self):
        """Gets the subscription of this ShopifySubscriptionSuspensionCreate.

            

        :return: The subscription of this ShopifySubscriptionSuspensionCreate.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this ShopifySubscriptionSuspensionCreate.

            

        :param subscription: The subscription of this ShopifySubscriptionSuspensionCreate.
        :type: int
        """
        if subscription is None:
            raise ValueError("Invalid value for `subscription`, must not be `None`")

        self._subscription = subscription
    
    @property
    def type(self):
        """Gets the type of this ShopifySubscriptionSuspensionCreate.

            

        :return: The type of this ShopifySubscriptionSuspensionCreate.
        :rtype: ShopifySubscriptionSuspensionType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShopifySubscriptionSuspensionCreate.

            

        :param type: The type of this ShopifySubscriptionSuspensionCreate.
        :type: ShopifySubscriptionSuspensionType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionSuspensionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionSuspensionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminal:

    swagger_types = {
    
        'configuration_version': 'PaymentTerminalConfigurationVersion',
        'default_currency': 'str',
        'external_id': 'str',
        'id': 'int',
        'identifier': 'str',
        'linked_space_id': 'int',
        'location_version': 'PaymentTerminalLocationVersion',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'state': 'PaymentTerminalState',
        'type': 'PaymentTerminalType',
        'version': 'int',
    }

    attribute_map = {
        'configuration_version': 'configurationVersion','default_currency': 'defaultCurrency','external_id': 'externalId','id': 'id','identifier': 'identifier','linked_space_id': 'linkedSpaceId','location_version': 'locationVersion','name': 'name','planned_purge_date': 'plannedPurgeDate','state': 'state','type': 'type','version': 'version',
    }

    
    _configuration_version = None
    _default_currency = None
    _external_id = None
    _id = None
    _identifier = None
    _linked_space_id = None
    _location_version = None
    _name = None
    _planned_purge_date = None
    _state = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration_version = kwargs.get('configuration_version', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.identifier = kwargs.get('identifier', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.location_version = kwargs.get('location_version', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def configuration_version(self):
        """Gets the configuration_version of this PaymentTerminal.

            

        :return: The configuration_version of this PaymentTerminal.
        :rtype: PaymentTerminalConfigurationVersion
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """Sets the configuration_version of this PaymentTerminal.

            

        :param configuration_version: The configuration_version of this PaymentTerminal.
        :type: PaymentTerminalConfigurationVersion
        """

        self._configuration_version = configuration_version
    
    @property
    def default_currency(self):
        """Gets the default_currency of this PaymentTerminal.

            

        :return: The default_currency of this PaymentTerminal.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this PaymentTerminal.

            

        :param default_currency: The default_currency of this PaymentTerminal.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentTerminal.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this PaymentTerminal.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentTerminal.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this PaymentTerminal.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminal.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentTerminal.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminal.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentTerminal.
        :type: int
        """

        self._id = id
    
    @property
    def identifier(self):
        """Gets the identifier of this PaymentTerminal.

            The identifier uniquely identifies the terminal. Normally it is visible on the device or in the display of the device.

        :return: The identifier of this PaymentTerminal.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this PaymentTerminal.

            The identifier uniquely identifies the terminal. Normally it is visible on the device or in the display of the device.

        :param identifier: The identifier of this PaymentTerminal.
        :type: str
        """

        self._identifier = identifier
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminal.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this PaymentTerminal.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminal.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminal.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def location_version(self):
        """Gets the location_version of this PaymentTerminal.

            

        :return: The location_version of this PaymentTerminal.
        :rtype: PaymentTerminalLocationVersion
        """
        return self._location_version

    @location_version.setter
    def location_version(self, location_version):
        """Sets the location_version of this PaymentTerminal.

            

        :param location_version: The location_version of this PaymentTerminal.
        :type: PaymentTerminalLocationVersion
        """

        self._location_version = location_version
    
    @property
    def name(self):
        """Gets the name of this PaymentTerminal.

            The terminal name is used internally to identify the terminal in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this PaymentTerminal.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentTerminal.

            The terminal name is used internally to identify the terminal in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this PaymentTerminal.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentTerminal.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this PaymentTerminal.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentTerminal.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentTerminal.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this PaymentTerminal.

            

        :return: The state of this PaymentTerminal.
        :rtype: PaymentTerminalState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentTerminal.

            

        :param state: The state of this PaymentTerminal.
        :type: PaymentTerminalState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this PaymentTerminal.

            

        :return: The type of this PaymentTerminal.
        :rtype: PaymentTerminalType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PaymentTerminal.

            

        :param type: The type of this PaymentTerminal.
        :type: PaymentTerminalType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminal.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this PaymentTerminal.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminal.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this PaymentTerminal.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractSpaceUpdate


class SpaceUpdate(AbstractSpaceUpdate):

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','version': 'version',
    }

    
    _id = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def id(self):
        """Gets the id of this SpaceUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SpaceUpdate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SpaceUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SpaceUpdate.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this SpaceUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SpaceUpdate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SpaceUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SpaceUpdate.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SpaceUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SpaceUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class ChargeBankTransaction(TransactionAwareEntity):

    swagger_types = {
    
        'bank_transaction': 'BankTransaction',
        'completion': 'int',
        'language': 'str',
        'space_view_id': 'int',
        'transaction': 'Transaction',
        'transaction_currency_amount': 'float',
        'transaction_currency_value_amount': 'float',
        'version': 'int',
    }

    attribute_map = {
        'bank_transaction': 'bankTransaction','completion': 'completion','language': 'language','space_view_id': 'spaceViewId','transaction': 'transaction','transaction_currency_amount': 'transactionCurrencyAmount','transaction_currency_value_amount': 'transactionCurrencyValueAmount','version': 'version',
    }

    
    _bank_transaction = None
    _completion = None
    _language = None
    _space_view_id = None
    _transaction = None
    _transaction_currency_amount = None
    _transaction_currency_value_amount = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.bank_transaction = kwargs.get('bank_transaction', None)
        self.completion = kwargs.get('completion', None)
        self.language = kwargs.get('language', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.transaction = kwargs.get('transaction', None)
        self.transaction_currency_amount = kwargs.get('transaction_currency_amount', None)
        self.transaction_currency_value_amount = kwargs.get('transaction_currency_value_amount', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def bank_transaction(self):
        """Gets the bank_transaction of this ChargeBankTransaction.

            

        :return: The bank_transaction of this ChargeBankTransaction.
        :rtype: BankTransaction
        """
        return self._bank_transaction

    @bank_transaction.setter
    def bank_transaction(self, bank_transaction):
        """Sets the bank_transaction of this ChargeBankTransaction.

            

        :param bank_transaction: The bank_transaction of this ChargeBankTransaction.
        :type: BankTransaction
        """

        self._bank_transaction = bank_transaction
    
    @property
    def completion(self):
        """Gets the completion of this ChargeBankTransaction.

            

        :return: The completion of this ChargeBankTransaction.
        :rtype: int
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this ChargeBankTransaction.

            

        :param completion: The completion of this ChargeBankTransaction.
        :type: int
        """

        self._completion = completion
    
    @property
    def language(self):
        """Gets the language of this ChargeBankTransaction.

            

        :return: The language of this ChargeBankTransaction.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ChargeBankTransaction.

            

        :param language: The language of this ChargeBankTransaction.
        :type: str
        """

        self._language = language
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this ChargeBankTransaction.

            

        :return: The space_view_id of this ChargeBankTransaction.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this ChargeBankTransaction.

            

        :param space_view_id: The space_view_id of this ChargeBankTransaction.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def transaction(self):
        """Gets the transaction of this ChargeBankTransaction.

            

        :return: The transaction of this ChargeBankTransaction.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this ChargeBankTransaction.

            

        :param transaction: The transaction of this ChargeBankTransaction.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def transaction_currency_amount(self):
        """Gets the transaction_currency_amount of this ChargeBankTransaction.

            Specify the posting amount in the transaction's currency.

        :return: The transaction_currency_amount of this ChargeBankTransaction.
        :rtype: float
        """
        return self._transaction_currency_amount

    @transaction_currency_amount.setter
    def transaction_currency_amount(self, transaction_currency_amount):
        """Sets the transaction_currency_amount of this ChargeBankTransaction.

            Specify the posting amount in the transaction's currency.

        :param transaction_currency_amount: The transaction_currency_amount of this ChargeBankTransaction.
        :type: float
        """

        self._transaction_currency_amount = transaction_currency_amount
    
    @property
    def transaction_currency_value_amount(self):
        """Gets the transaction_currency_value_amount of this ChargeBankTransaction.

            

        :return: The transaction_currency_value_amount of this ChargeBankTransaction.
        :rtype: float
        """
        return self._transaction_currency_value_amount

    @transaction_currency_value_amount.setter
    def transaction_currency_value_amount(self, transaction_currency_value_amount):
        """Sets the transaction_currency_value_amount of this ChargeBankTransaction.

            

        :param transaction_currency_value_amount: The transaction_currency_value_amount of this ChargeBankTransaction.
        :type: float
        """

        self._transaction_currency_value_amount = transaction_currency_value_amount
    
    @property
    def version(self):
        """Gets the version of this ChargeBankTransaction.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ChargeBankTransaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ChargeBankTransaction.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ChargeBankTransaction.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ChargeBankTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ChargeBankTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class LineItemReductionCreate:

    swagger_types = {
    
        'line_item_unique_id': 'str',
        'quantity_reduction': 'float',
        'unit_price_reduction': 'float',
    }

    attribute_map = {
        'line_item_unique_id': 'lineItemUniqueId','quantity_reduction': 'quantityReduction','unit_price_reduction': 'unitPriceReduction',
    }

    
    _line_item_unique_id = None
    _quantity_reduction = None
    _unit_price_reduction = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.line_item_unique_id = kwargs.get('line_item_unique_id')

        self.quantity_reduction = kwargs.get('quantity_reduction')

        self.unit_price_reduction = kwargs.get('unit_price_reduction')

        

    
    @property
    def line_item_unique_id(self):
        """Gets the line_item_unique_id of this LineItemReductionCreate.

            The unique id identifies the line item on which the reduction is applied on.

        :return: The line_item_unique_id of this LineItemReductionCreate.
        :rtype: str
        """
        return self._line_item_unique_id

    @line_item_unique_id.setter
    def line_item_unique_id(self, line_item_unique_id):
        """Sets the line_item_unique_id of this LineItemReductionCreate.

            The unique id identifies the line item on which the reduction is applied on.

        :param line_item_unique_id: The line_item_unique_id of this LineItemReductionCreate.
        :type: str
        """
        if line_item_unique_id is None:
            raise ValueError("Invalid value for `line_item_unique_id`, must not be `None`")
        if line_item_unique_id is not None and len(line_item_unique_id) > 200:
            raise ValueError("Invalid value for `line_item_unique_id`, length must be less than or equal to `200`")

        self._line_item_unique_id = line_item_unique_id
    
    @property
    def quantity_reduction(self):
        """Gets the quantity_reduction of this LineItemReductionCreate.

            

        :return: The quantity_reduction of this LineItemReductionCreate.
        :rtype: float
        """
        return self._quantity_reduction

    @quantity_reduction.setter
    def quantity_reduction(self, quantity_reduction):
        """Sets the quantity_reduction of this LineItemReductionCreate.

            

        :param quantity_reduction: The quantity_reduction of this LineItemReductionCreate.
        :type: float
        """
        if quantity_reduction is None:
            raise ValueError("Invalid value for `quantity_reduction`, must not be `None`")

        self._quantity_reduction = quantity_reduction
    
    @property
    def unit_price_reduction(self):
        """Gets the unit_price_reduction of this LineItemReductionCreate.

            

        :return: The unit_price_reduction of this LineItemReductionCreate.
        :rtype: float
        """
        return self._unit_price_reduction

    @unit_price_reduction.setter
    def unit_price_reduction(self, unit_price_reduction):
        """Sets the unit_price_reduction of this LineItemReductionCreate.

            

        :param unit_price_reduction: The unit_price_reduction of this LineItemReductionCreate.
        :type: float
        """
        if unit_price_reduction is None:
            raise ValueError("Invalid value for `unit_price_reduction`, must not be `None`")

        self._unit_price_reduction = unit_price_reduction
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(LineItemReductionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, LineItemReductionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ClientError:

    swagger_types = {
    
        '_date': 'str',
        'default_message': 'str',
        'id': 'str',
        'message': 'str',
        'type': 'ClientErrorType',
    }

    attribute_map = {
        '_date': 'date','default_message': 'defaultMessage','id': 'id','message': 'message','type': 'type',
    }

    
    __date = None
    _default_message = None
    _id = None
    _message = None
    _type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self._date = kwargs.get('_date', None)
        self.default_message = kwargs.get('default_message', None)
        self.id = kwargs.get('id', None)
        self.message = kwargs.get('message', None)
        self.type = kwargs.get('type', None)
        

    
    @property
    def _date(self):
        """Gets the _date of this ClientError.

            Date when an error has occurred.

        :return: The _date of this ClientError.
        :rtype: str
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this ClientError.

            Date when an error has occurred.

        :param _date: The _date of this ClientError.
        :type: str
        """

        self.__date = _date
    
    @property
    def default_message(self):
        """Gets the default_message of this ClientError.

            The error message which is translated into the default language (i.e. English).

        :return: The default_message of this ClientError.
        :rtype: str
        """
        return self._default_message

    @default_message.setter
    def default_message(self, default_message):
        """Sets the default_message of this ClientError.

            The error message which is translated into the default language (i.e. English).

        :param default_message: The default_message of this ClientError.
        :type: str
        """

        self._default_message = default_message
    
    @property
    def id(self):
        """Gets the id of this ClientError.

            Unique identifier of an error.

        :return: The id of this ClientError.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ClientError.

            Unique identifier of an error.

        :param id: The id of this ClientError.
        :type: str
        """

        self._id = id
    
    @property
    def message(self):
        """Gets the message of this ClientError.

            The error message which is translated in into the language of the client.

        :return: The message of this ClientError.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ClientError.

            The error message which is translated in into the language of the client.

        :param message: The message of this ClientError.
        :type: str
        """

        self._message = message
    
    @property
    def type(self):
        """Gets the type of this ClientError.

            The type of the client error.

        :return: The type of this ClientError.
        :rtype: ClientErrorType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ClientError.

            The type of the client error.

        :param type: The type of this ClientError.
        :type: ClientErrorType
        """

        self._type = type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ClientError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ClientError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ConnectorInvocationStage(Enum):
    
    PAYMENT_METHOD_LIST = "PAYMENT_METHOD_LIST"
    FORM_GENERATION = "FORM_GENERATION"
    VALIDATION = "VALIDATION"
    AUTHORIZATION = "AUTHORIZATION"

